@@ -748,11 +748,6 @@ apply_name2gtype_call( Reduce *rc, const char *name,
 	PEPOINTRIGHT( arg[0], &rhs );
 	(void) reduce_get_string( rc, &rhs, txt, FILENAME_MAX );
 
-	/* Hack ... map the old vips7 names to the new ones.
-	 */
-	if( strcmp( txt, "im_ref_string" ) == 0 )
-		strcpy( txt, "vips_ref_string" );
-
 	gtype = g_type_from_name( txt );
 
 	if( !heap_real_new( rc->heap, gtype, out ) )
@@ -808,6 +803,33 @@ apply_vo_new_call( Reduce *rc,
 	vo_object_new( rc, buf, &required, &optional, out );
 }
 
+/* Args for "vips_call". 
+ */
+static BuiltinTypeSpot *vo_call_args[] = { 
+	&string_spot,
+	&list_spot,
+	&list_spot 
+};
+
+/* Do a vips_call call.
+ */
+static void
+apply_vo_call_call( Reduce *rc, 
+	const char *name, HeapNode **arg, PElement *out )
+{
+	PElement rhs;
+	char buf[256];
+	PElement required;
+	PElement optional;
+
+	PEPOINTRIGHT( arg[2], &rhs );
+	reduce_get_string( rc, &rhs, buf, 256 );
+	PEPOINTRIGHT( arg[1], &required );
+	PEPOINTRIGHT( arg[0], &optional );
+
+	vo_call( rc, buf, &required, &optional, out );
+}
+
 /* All ip's builtin functions. 
  */
 static BuiltinInfo builtin_table[] = {
@@ -826,6 +848,8 @@ static BuiltinInfo builtin_table[] = {
 	 */
 	{ "vips_object_new", FALSE, IM_NUMBER( vo_new_args ), 
 		&vo_new_args[0], apply_vo_new_call },
+	{ "vips_call", FALSE, IM_NUMBER( vo_call_args ), 
+		&vo_call_args[0], apply_vo_call_call },
 
 	/* Predicates.
 	 */
