@@ -400,77 +400,6 @@ cache_history_sanity( void )
 	 */
 	g_hash_table_foreach( cache_history_table,
 		(GHFunc) cache_history_sanity_sub, NULL );
-
-	/* Everything that's on the LRU should be in the global cache_info
-	 * list.
-	 */
-	for( p = cache_history_lru->list; p; p = p->next ) {
-		CallInfo *vi = (CallInfo *) p->data;
-
-		/* Need to build with DEBUG on before cache_info_all is
-		 * maintained.
-		 */
-		g_assert( g_slist_find( cache_info_all, vi ) );
-	}
-
-	/* Everything on cache_info_all that's not in cache_history_table should
-	 * have in_cache FALSE.
-	 */
-	for( p = cache_info_all; p; p = p->next ) {
-		CallInfo *vi = (CallInfo *) p->data;
-
-		if( !g_hash_table_lookup( cache_history_table, vi ) )
-			g_assert( !vi->in_cache );
-	}
-
-	/* Every input image argument on every in-cache call should be sane.
-	 */
-	for( p = cache_info_all; p; p = p->next ) {
-		CallInfo *vi = (CallInfo *) p->data;
-		int i;
-
-		if( !vi->in_cache )
-			continue;
-
-		for( i = 0; i < vi->fn->argc; i++ ) {
-			im_type_desc *ty = vi->fn->argv[i].desc;
-
-			if( !call_type_needs_input( ty ) )
-				continue;
-
-			if( strcmp( ty->type, IM_TYPE_IMAGE ) == 0 ) {
-				IMAGE *im = (IMAGE *) vi->vargv[i];
-
-				g_assert( !im_image_sanity( im ) );
-			}
-			else if( strcmp( ty->type, IM_TYPE_IMAGEVEC ) == 0 ) {
-				im_imagevec_object *iv = 
-					(im_imagevec_object *) vi->vargv[i];
-				int j;
-
-				for( j = 0; j < iv->n; j++) 
-					g_assert( !im_image_sanity( 
-						iv->vec[j] ) );
-			}
-		}
-	}
-
-	/* All the output images should be sane.
-	 */
-	for( p = cache_info_all; p; p = p->next ) {
-		CallInfo *vi = (CallInfo *) p->data;
-		int i;
-
-		if( !vi->in_cache )
-			continue;
-
-		for( i = 0; i < vi->noutii; i++ ) {
-			IMAGE *im;
-
-			if( (im = imageinfo_get( FALSE, vi->outii[i] )) )
-				g_assert( !im_image_sanity( im ) );
-		}
-	}
 }
 #endif /*DEBUG_HISTORY_SANITY */
 
