@@ -1830,6 +1830,13 @@ heap_ip_to_gvalue( PElement *in, GValue *out )
 		printf( "ip_to_gvalue: no complex gtype!\n" );
 		return( FALSE );
 	}
+	else if( PEISIMAGE( in ) ) {
+		Imageinfo *ii = PEGETII( in );
+		VipsImage *im = imageinfo_get( FALSE, ii );
+
+		g_value_init( out, VIPS_TYPE_IMAGE );
+		g_value_set_object( out, im );
+	}
 	else if( PEISLIST( in ) ) {
 		gboolean result;
 
@@ -1927,7 +1934,17 @@ heap_gvalue_to_ip( GValue *in, PElement *out )
 		Managed *managed;
 
 		object = g_value_get_object( in );
-		managed = MANAGED( managedgobject_new( heap, object ) );
+
+		if( VIPS_IS_IMAGE( object ) ) {
+			VipsImage *image = VIPS_IMAGE( object ); 
+
+			g_object_ref( image ); 
+			managed = MANAGED( imageinfo_new( main_imageinfogroup, 
+				heap, image, image->filename ) );
+		}
+		else 
+			managed = MANAGED( managedgobject_new( heap, object ) );
+
 		PEPUTP( out, ELEMENT_MANAGED, managed );
 	}
 	else if( g_value_type_transformable( G_VALUE_TYPE( in ), 
