@@ -414,6 +414,7 @@ gboolean heap_get_real( PElement *base, double *out );
 gboolean heap_get_class( PElement *base, PElement *out );
 gboolean heap_get_image( PElement *base, Imageinfo **out );
 int heap_get_realvec( PElement *base, double *buf, int n );
+int heap_get_imagevec( PElement *base, Imageinfo **buf, int n );
 gboolean heap_get_matrix_size( PElement *base, int *xsize, int *ysize );
 gboolean heap_get_matrix( PElement *base, 
 	double *buf, int n, int *xsize, int *ysize );
@@ -437,3 +438,12 @@ gboolean heap_copy( Heap *heap, Compile *compile, PElement *out );
 
 gboolean heap_ip_to_gvalue( PElement *in, GValue *out );
 gboolean heap_gvalue_to_ip( GValue *in, PElement *out );
+
+void graph_node( Heap *heap, VipsBuf *buf, HeapNode *root, gboolean fn );
+void graph_pelement( Heap *heap, VipsBuf *buf, PElement *root, gboolean fn );
+void graph_element( Heap *heap, VipsBuf *buf, Element *root, gboolean fn );
+void graph_pointer( PElement *root );
+
+/* Reduce and print, csh-style output.
+ */
+void graph_value( PElement *root );
