@@ -672,10 +672,8 @@ imageinfo_proxy_eval( Imageinfoproxy *proxy )
 
 	if( imageinfo && imageinfo->im->time ) 
 		if( progress_update_percent( imageinfo->im->time->percent,
-			imageinfo->im->time->eta ) ) {
-			im_error( "nip2", _( "User cancelled operation" ) );
+			imageinfo->im->time->eta ) ) 
 			return( -1 );
-		}
 
 	return( 0 );
 }
@@ -949,16 +947,16 @@ imageinfo_attach_check( Imageinfo *imageinfo )
 		IM_FREEF( g_source_remove, imageinfo->check_tid );
 }
 
-/* Open a filename for input.
+/* Open a filename for input. The filenmae can have an embedded mode. 
  */
 Imageinfo *
 imageinfo_new_input( Imageinfogroup *imageinfogroup, GtkWidget *parent,
-	Heap *heap, const char *filename )
+	Heap *heap, const char *name )
 {
 	Imageinfo *imageinfo;
 	ImageinfoOpen open;
 
-	if( (imageinfo = imageinfogroup_lookup( imageinfogroup, filename )) ) {
+	if( (imageinfo = imageinfogroup_lookup( imageinfogroup, name )) ) {
 		/* We always make a new non-heap pointer.
 		 */
 		MANAGED_REF( imageinfo );
@@ -967,15 +965,15 @@ imageinfo_new_input( Imageinfogroup *imageinfogroup, GtkWidget *parent,
 
 	open.imageinfogroup = imageinfogroup;
 	open.heap = heap;
-	open.filename = filename;
+	open.filename = name;
 	open.parent = parent;
 
         if( !(imageinfo = (Imageinfo *) callv_string_filename( 
 		(callv_string_fn) imageinfo_open_image_input, 
-		filename, &open, NULL, NULL )) ) {
+		name, &open, NULL, NULL )) ) {
 		error_top( _( "Unable to open image." ) );
 		error_sub( _( "Unable to open file \"%s\" as image." ), 
-			filename );
+			name );
 		error_vips();
                 return( NULL );
         }
@@ -1095,23 +1093,13 @@ imageinfo_same_underlying( Imageinfo *imageinfo[], int n )
 gboolean
 imageinfo_write( Imageinfo *imageinfo, const char *name )
 {
-	Imageinfogroup *imageinfogroup = 
-		IMAGEINFOGROUP( ICONTAINER( imageinfo )->parent );
 	IMAGE *im = imageinfo_get( FALSE, imageinfo );
-	char filename[FILENAME_MAX];
-	char filemode[FILENAME_MAX];
-
-	im_filename_split( name, filename, filemode );
-
-	if( (imageinfo = imageinfogroup_lookup( imageinfogroup, filename )) ) {
-                error_top( _( "Unable to write to file." ) );
-		error_sub( _( "File \"%s\" is already open for read." ), 
-			filename );
-
-                return( FALSE );
-	}
 
 	if( vips_format_write( im, name ) ) {
+		char filename[FILENAME_MAX];
+		char mode[FILENAME_MAX];
+
+		im_filename_split( name, filename, mode );
 		error_top( _( "Unable to write to file." ) );
 		error_sub( _( "Error writing image to file \"%s\"." ), 
 			filename );
