@@ -319,6 +319,23 @@ model_edit( GtkWidget *parent, Model *model )
 	return( NULL );
 }
 
+void *
+model_header( GtkWidget *parent, Model *model )
+{
+	ModelClass *model_class = MODEL_GET_CLASS( model );
+
+	if( model_class->header )
+		model_class->header( parent, model );
+	else {
+		error_top( _( "Not implemented." ) );
+		error_sub( _( "_%s() not implemented for class \"%s\"." ), 
+			"header", 
+			G_OBJECT_CLASS_NAME( model_class ) );
+	}
+
+	return( NULL );
+}
+
 void *
 model_save( Model *model, xmlNode *xnode )
 {
