@@ -28,8 +28,8 @@
  */
 
 /*
-#define DEBUG
 #define DEBUG_MEMUSE
+#define DEBUG
  */
 
 #include "ip.h"
@@ -49,11 +49,11 @@ static guint progress_signals[SIG_LAST] = { 0 };
 
 /* Delay before we start showing busy feedback.
  */
-static const double progress_busy_delay = 2.0;
+static const double progress_busy_delay = 1.0;
 
 /* Delay between busy updates.
  */
-static const double progress_update_interval = 0.2;
+static const double progress_update_interval = 0.1;
 
 void
 progress_begin( void )
@@ -82,12 +82,17 @@ progress_begin( void )
 static void
 progress_update( Progress *progress )
 {
-	/* Handle delayed emission of "begin".
+	/* Don't show the process and cancel button for a bit.
 	 */
 	if( progress->count ) {
+		double elapsed = g_timer_elapsed( progress->busy_timer, NULL );
+
 		if( !progress->busy && 
-			g_timer_elapsed( progress->busy_timer, NULL ) > 
-			progress_busy_delay ) {
+			elapsed > progress_busy_delay ) {
+#ifdef DEBUG
+			printf( "progress_update: displaying progress bar\n" );
+#endif /*DEBUG*/
+
 			g_signal_emit( G_OBJECT( progress ), 
 				progress_signals[SIG_BEGIN], 0 );
 			progress->busy = TRUE;
@@ -101,6 +106,10 @@ progress_update( Progress *progress )
 		progress_update_interval ) {
 		gboolean cancel;
 
+#ifdef DEBUG
+		printf( "progress_update:\n" );
+#endif /*DEBUG*/
+
 		g_timer_start( progress->update_timer );
 
 		/* Overwrite the message if we're cancelling.
@@ -118,15 +127,10 @@ progress_update( Progress *progress )
 		if( cancel )
 			progress->cancel = TRUE;
 
-		/* Mysteriously this can sometimes get stuck, eg. if you drag
-		 * multiple workspaces to the main window.
-
-			while( g_main_context_iteration( NULL, FALSE ) )
-				;
-
-		 * Just run once.
+		/* Rather dangerous, but we need this to give nice updates
+		 * for the feedback thing.
 		 */
-		g_main_context_iteration( NULL, FALSE );
+		process_events();
 
 #ifdef DEBUG_MEMUSE
 		printf( "progress_update:\n" );
