@@ -147,8 +147,9 @@ Symbol *symbol_get_scope( Symbol *sym );
 void symbol_qualified_name( Symbol *sym, VipsBuf *buf );
 void symbol_qualified_name_relative( Symbol *context, 
 	Symbol *sym, VipsBuf *buf );
+void *symbol_name_error( Symbol *sym, VipsBuf *buf );
 const char *symbol_name( Symbol *sym );
-void symbol_name_print( Symbol *sym );
+void *symbol_name_print( Symbol *sym );
 const char *symbol_name_scope( Symbol *sym );
 void symbol_name_scope_print( Symbol *sym );
 
