@@ -64,24 +64,6 @@ toolkit_dispose( GObject *gobject )
 	G_OBJECT_CLASS( parent_class )->dispose( gobject );
 }
 
-static void
-toolkit_finalize( GObject *gobject )
-{
-	Toolkit *kit;
-
-#ifdef DEBUG
-	printf( "toolkit_finalize: %p %s\n", 
-		gobject, NN( IOBJECT( gobject )->name ) );
-#endif /*DEBUG*/
-
-	g_return_if_fail( gobject != NULL );
-	g_return_if_fail( IS_TOOLKIT( gobject ) );
-
-	kit = TOOLKIT( gobject );
-
-	G_OBJECT_CLASS( parent_class )->finalize( gobject );
-}
-
 static void
 toolkit_changed( iObject *iobject )
 {
@@ -163,7 +145,6 @@ toolkit_class_init( ToolkitClass *class )
 	/* Init methods.
 	 */
 	gobject_class->dispose = toolkit_dispose;
-	gobject_class->finalize = toolkit_finalize;
 
 	iobject_class->info = toolkit_info;
 	iobject_class->changed = toolkit_changed;
