@@ -51,7 +51,7 @@ toolkitview_destroy( GtkObject *object )
 	kview = TOOLKITVIEW( object );
 
 #ifdef DEBUG
-	printf( "toolkitview_destroy:  0x%x\n", (unsigned int) object );
+	printf( "toolkitview_destroy: %p\n", object );
 #endif /*DEBUG*/
 
 	DESTROY_GTK( kview->menu );
@@ -64,7 +64,7 @@ static void
 toolkitview_finalize( GObject *gobject )
 {
 #ifdef DEBUG
-	printf( "toolkitview_finalize: 0x%x\n", (unsigned int) gobject );
+	printf( "toolkitview_finalize: %p\n", gobject );
 #endif /*DEBUG*/
 
 	G_OBJECT_CLASS( parent_class )->finalize( gobject );
