@@ -42,44 +42,34 @@
 typedef struct _Vo {
 	 Reduce *rc;
 
-	/* Operation we are building.
+	/* Object we are building.
 	 */
-	char *name;
-	GType type;
 	VipsObject *object;
+	const char *name;
 
 	/* Required args supplied to us from nip.
 	 */
 	PElement args[MAX_VIPS_ARGS];
 	int nargs_supplied;
 
-	/* Number of required input args the operation actually has.
+	/* Number of required input args the object has.
 	 */
 	int nargs_required;
 
-	/* Number of ouput args the operation has.
+	/* Number of output args the object has.
 	 */
 	int nargs_output;
 
-	/* Output objects we have built and should unref.
+	/* A place to build the output, safe from the GC.
 	 */
-	GSList *unref;
+	Element out;
 } Vo;
 
 static void
 vo_free( Vo *vo )
 {
-	IM_FREE( vo->name );
-
-	while( vo->unref ) {
-		GObject *object = G_OBJECT( vo->unref->data );
-
-		g_object_unref( object );
-
-		vo->unref = g_slist_remove( vo->unref, object );
-	}
-
-	IM_FREEF( g_object_unref, vo->object );
+	heap_unregister_element( vo->rc->heap, &vo->out );
+	VIPS_UNREF( vo->object );
 
 	im_free( vo );
 }
@@ -87,33 +77,24 @@ vo_free( Vo *vo )
 static Vo *
 vo_new( Reduce *rc, const char *name )
 {
-	GType type;
+	VipsObjectClass *class;
 	Vo *vo;
 
-	if( !(type = vips_type_find( "VipsObject", name )) ) {
-		error_top( _( "No such type." ) );
-		error_sub( _( "Type \"%s\" not found as a subclass "
-			"of VipsObject." ), name );
+	if( !(class = vips_class_find( "VipsObject", name )) )
 		return( NULL );
-	}
 
-	if( !(vo = INEW( NULL, Vo )) )
+	if( !(vo = INEW( NULL, Vo )) ) 
 		return( NULL );
 	vo->rc = rc;
-	vo->name = NULL;
-	vo->type = type;
-	vo->object = NULL;
+	vo->object = g_object_new( G_OBJECT_CLASS_TYPE( class ), NULL );
+	vo->name = class->nickname;
 	vo->nargs_supplied = 0;
 	vo->nargs_required = 0;
 	vo->nargs_output = 0;
-	vo->unref = NULL;
+	vo->out.type = ELEMENT_NOVAL;
+	vo->out.ele = (void *) 12;
 
-	if( !(vo->name = im_strdupn( name )) ) {
-		vo_free( vo );
-		return( NULL );
-	}
-
-	vo->object = VIPS_OBJECT( g_object_new( type, NULL ) );
+	heap_register_element( rc->heap, &vo->out );
 
 	return( vo );
 }
@@ -140,30 +121,23 @@ vo_set_required_input( VipsObject *object, GParamSpec *pspec,
         VipsArgumentClass *argument_class, 
 	VipsArgumentInstance *argument_instance, Vo *vo )
 {
-	VipsArgument *argument = (VipsArgument *) argument_class;
-	const char *name = argument->pspec->name;
-
 	/* Looking for required input args ... these are the ones we can set
 	 * from the supplied required list. 
 	 */
 	if( (argument_class->flags & VIPS_ARGUMENT_REQUIRED) &&
-		!(argument_class->flags & VIPS_ARGUMENT_CONSTRUCT) &&
+		(argument_class->flags & VIPS_ARGUMENT_CONSTRUCT) &&
+		(argument_class->flags & VIPS_ARGUMENT_INPUT) &&
 		!argument_instance->assigned &&
 		vo->nargs_required < vo->nargs_supplied ) {
-		/* Also insist we are under the nargs
-		 * limit ... our caller checks the numbers match and makes the
-		 * error message.
-		 */
-		if( vo->nargs_required < vo->nargs_supplied ) {
-			int i = vo->nargs_required;
-			GValue value = { 0 };
+		const char *name = g_param_spec_get_name( pspec );
+		int i = vo->nargs_required;
 
-			if( !heap_ip_to_gvalue( &vo->args[i], &value ) )
-				return( object );
-			g_object_set_property( G_OBJECT( object ), 
-				name, &value );
-			g_value_unset( &value );
-		}
+		GValue value = { 0 };
+
+		if( !heap_ip_to_gvalue( &vo->args[i], &value ) )
+			return( object );
+		g_object_set_property( G_OBJECT( object ), name, &value );
+		g_value_unset( &value );
 
 		vo->nargs_required += 1;
 	}
@@ -174,20 +148,34 @@ vo_set_required_input( VipsObject *object, GParamSpec *pspec,
 static void *
 vo_set_optional_arg( const char *name, PElement *value, Vo *vo )
 {
-	GValue gvalue = { 0 };
+	GParamSpec *pspec;
+	VipsArgumentClass *argument_class;
+	VipsArgumentInstance *argument_instance;
+
+	/* Looking for construct-time optional input args.
+	 */
 
 	/* For optional args, we should ignore properties that don't exist. For
 	 * example, we might supply ($sharpening => 12) to all interpolators,
 	 * though only one interpolator uses this property.
 	 */
-	if( !g_object_class_find_property( G_OBJECT_GET_CLASS( vo->object ), 
-		name ) )
+	if( vips_object_get_argument( vo->object, name,
+		&pspec, &argument_class, &argument_instance ) )
 		return( NULL );
 
-	if( !heap_ip_to_gvalue( value, &gvalue ) )
-		return( value );
-	g_object_set_property( G_OBJECT( vo->object ), name, &gvalue );
-	g_value_unset( &gvalue );
+	if( !(argument_class->flags & VIPS_ARGUMENT_REQUIRED) &&
+		(argument_class->flags & VIPS_ARGUMENT_CONSTRUCT) &&
+		(argument_class->flags & VIPS_ARGUMENT_INPUT) &&
+		!argument_instance->assigned ) {
+		GValue gvalue = { 0 };
+
+		if( !heap_ip_to_gvalue( value, &gvalue ) ) {
+			g_value_unset( &gvalue );
+			return( value );
+		}
+		g_object_set_property( G_OBJECT( vo->object ), name, &gvalue );
+		g_value_unset( &gvalue );
+	}
 
 	return( NULL );
 }
@@ -196,59 +184,31 @@ vo_set_optional_arg( const char *name, PElement *value, Vo *vo )
  * etc.
  */
 static gboolean
-vo_set_optional( Vo *vo, PElement *list )
+vo_set_optional( Vo *vo, PElement *optional )
 {
-	if( heap_map_dict( list,
+	if( heap_map_dict( optional,
 		(heap_map_dict_fn) vo_set_optional_arg, vo, NULL ) )
 		return( FALSE );
 
 	return( TRUE );
 }
 
-static gboolean
-vo_build_result( Vo *vo, PElement *out )
-{
-	/* We don't have it yet, but we should loop over args looking for
-	 * outputs and building a list. Paste this code back in at some
-	 * point.
-	 */
-	Managedgobject *managedgobject;
-
-	if( !(managedgobject = managedgobject_new( vo->rc->heap, 
-		G_OBJECT( vo->object ) )) )
-		return( FALSE );
-
-	PEPUTP( out, ELEMENT_MANAGED, managedgobject );
-
-	return( TRUE );
-}
-
-/* We know we have three args: name, required, optional.
+/* Make a vo and supply args from nip2.
  */
-void
-vo_object_new( Reduce *rc, const char *name, 
-	PElement *required, PElement *optional, PElement *out )
+static gboolean
+vo_args( Vo *vo, PElement *required, PElement *optional )
 {
-	Vo *vo;
-
-	if( !(vo = vo_new( rc, name )) ) 
-		reduce_throw( rc );
-
 	/* Gather supplied required input args list.
 	 */
 	if( heap_map_list( required, 
-		(heap_map_list_fn) vo_gather_required, vo, NULL ) ) {
-		vo_free( vo );
-		reduce_throw( rc );
-	}
+		(heap_map_list_fn) vo_gather_required, vo, NULL ) ) 
+		return( FALSE );
 
 	/* Set required input arguments.
 	 */
 	if( vips_argument_map( VIPS_OBJECT( vo->object ),
-		(VipsArgumentMapFn) vo_set_required_input, vo, NULL ) ) {
-		vo_free( vo );
-		reduce_throw( rc );
-	}
+		(VipsArgumentMapFn) vo_set_required_input, vo, NULL ) ) 
+		return( FALSE );
 	if( vo->nargs_supplied != vo->nargs_required ) {
 		error_top( _( "Wrong number of required arguments." ) );
 		error_sub( _( "Operation \"%s\" has %d required arguments, "
@@ -256,24 +216,30 @@ vo_object_new( Reduce *rc, const char *name,
 			vo->name,
 			vo->nargs_required,
 			vo->nargs_supplied );
-		vo_free( vo );
+		return( FALSE );
 	}
 
-	/* Init required output arguments.
-
-	   	we don't have any output args yet: paste this stuff back in 
-		once we have a VipsOperation subclass
-
-	if( vips__argument_map( VIPS_OBJECT( vo->operation ),
-		(VipsArgumentMapFn) vo_set_required_output, vo, NULL ) ) {
-		vo_free( vo );
-		reduce_throw( rc );
-	}
-	 */
-
 	/* Set all optional input args.
 	 */
-	if( !vo_set_optional( vo, optional ) ) {
+	if( !vo_set_optional( vo, optional ) ) 
+		return( FALSE );
+
+	return( TRUE );
+}
+
+/* Make a VipsObject.
+ */
+void
+vo_object_new( Reduce *rc, const char *name, 
+	PElement *required, PElement *optional, PElement *out )
+{
+	Vo *vo;
+	Managedgobject *managedgobject;
+
+	if( !(vo = vo_new( rc, name )) ) 
+		reduce_throw( rc );
+
+	if( !vo_args( vo, required, optional ) ) {
 		vo_free( vo );
 		reduce_throw( rc );
 	}
@@ -287,13 +253,16 @@ vo_object_new( Reduce *rc, const char *name,
 		reduce_throw( rc );
 	}
 
-	/* Build the return value.
+	/* Return the constructed object.
 	 */
-	if( !vo_build_result( vo, out ) ) {
+	if( !(managedgobject = managedgobject_new( vo->rc->heap, 
+		G_OBJECT( vo->object ) )) ) {
 		vo_free( vo );
 		reduce_throw( rc );
 	}
 
+	PEPUTP( out, ELEMENT_MANAGED, managedgobject );
+
 #ifdef DEBUG
 {
 	char txt[1000];
@@ -306,3 +275,148 @@ vo_object_new( Reduce *rc, const char *name,
 
 	vo_free( vo );
 }
+
+/* Looking for required output args ... append to out.
+ */
+static void *
+vo_get_required_output( VipsObject *object, GParamSpec *pspec,
+        VipsArgumentClass *argument_class, 
+	VipsArgumentInstance *argument_instance, Vo *vo, PElement *out )
+{
+	if( (argument_class->flags & VIPS_ARGUMENT_REQUIRED) &&
+		(argument_class->flags & VIPS_ARGUMENT_OUTPUT) &&
+		argument_instance->assigned ) {
+		const char *name = g_param_spec_get_name( pspec );
+		GType type = G_PARAM_SPEC_VALUE_TYPE( pspec );
+		PElement lhs;
+
+		GValue value = { 0 };
+
+		if( !heap_list_add( vo->rc->heap, out, &lhs ) )
+			return( object );
+		g_value_init( &value, type );
+		g_object_get_property( G_OBJECT( object ), name, &value );
+		if( !heap_gvalue_to_ip( &value, &lhs ) ) {
+			g_value_unset( &value );
+			return( object );
+		}
+		g_value_unset( &value );
+
+		(void) heap_list_next( out );
+	}
+
+	return( NULL );
+}
+
+/* Looking for construct-time optional output args. Append them to out.
+ */
+static void *
+vo_get_optional_arg( const char *name, PElement *value, Vo *vo, PElement *out )
+{
+	GParamSpec *pspec;
+	VipsArgumentClass *argument_class;
+	VipsArgumentInstance *argument_instance;
+
+	if( vips_object_get_argument( vo->object, name,
+		&pspec, &argument_class, &argument_instance ) )
+		return( NULL );
+
+	if( !(argument_class->flags & VIPS_ARGUMENT_REQUIRED) &&
+		(argument_class->flags & VIPS_ARGUMENT_OUTPUT) &&
+		argument_instance->assigned ) {
+		GType type = G_PARAM_SPEC_VALUE_TYPE( pspec );
+		GValue gvalue = { 0 };
+		PElement lhs;
+
+		if( !heap_list_add( vo->rc->heap, out, &lhs ) )
+			return( value );
+		g_value_init( &gvalue, type );
+		g_object_get_property( G_OBJECT( vo->object ), name, &gvalue );
+		if( !heap_gvalue_to_ip( &gvalue, &lhs ) ) {
+			g_value_unset( &gvalue );
+			return( value );
+		}
+		g_value_unset( &gvalue );
+
+		(void) heap_list_next( out );
+	}
+
+	return( NULL );
+}
+
+/* Get a set of optional args ... of the form [["caption", []], ["label", []]]
+ * etc.
+ */
+static gboolean
+vo_get_optional( Vo *vo, PElement *optional, PElement *out )
+{
+	if( heap_map_dict( optional,
+		(heap_map_dict_fn) vo_get_optional_arg, vo, out ) )
+		return( FALSE );
+
+	return( TRUE );
+}
+
+/* Run a VipsOperation. Like vo_object_new(), but we return the output args
+ * rather than the operation.
+ */
+void
+vo_call( Reduce *rc, const char *name, 
+	PElement *required, PElement *optional, PElement *out )
+{
+	Vo *vo;
+	PElement pe;
+
+	if( !(vo = vo_new( rc, name )) ) 
+		reduce_throw( rc );
+
+	if( !vo_args( vo, required, optional ) ) {
+		vo_free( vo );
+		reduce_throw( rc );
+	}
+
+	/* Ask the object to construct. This can update vo->operation with an
+	 * old one from the cache.
+	 */
+	if( vips_cache_operation_buildp( (VipsOperation **) &vo->object ) ) {
+		error_top( _( "VIPS library error." ) );
+		error_sub( _( "Unable to build object." ) );
+		vips_object_unref_outputs( vo->object );
+		vo_free( vo );
+		reduce_throw( rc );
+	}
+
+	/* We can't build the output object directly on out, since it might be
+	 * one of our inputs. We use the safe Element in vo for the build,
+	 * then copy at the end.
+	 */
+
+	/* Empty output list.
+	 */
+	PEPOINTE( &pe, &vo->out );
+	heap_list_init( &pe );
+
+	/* Append required outputs.
+	 */
+	if( vips_argument_map( VIPS_OBJECT( vo->object ),
+		(VipsArgumentMapFn) vo_get_required_output, vo, &pe ) ) {
+		vips_object_unref_outputs( vo->object );
+		vo_free( vo );
+		reduce_throw( rc );
+	}
+
+	/* Append optional outputs.
+	 */
+	if( !vo_get_optional( vo, optional, &pe ) ) {
+		vips_object_unref_outputs( vo->object );
+		vo_free( vo );
+		reduce_throw( rc );
+	}
+
+	/* Now write the output object to out.
+	 */
+	PEPUTE( out, &vo->out );
+
+	vips_object_unref_outputs( vo->object );
+	vo_free( vo );
+}
